# <img src="https://raw.githubusercontent.com/llnl/thicket/develop/logo-notext.png" width="64" valign="middle" alt="thicket"/> Thicket

[![Build Status](https://github.com/llnl/thicket/actions/workflows/unit-tests.yaml/badge.svg)](https://github.com/llnl/thicket/actions)
[![Read the Docs](http://readthedocs.org/projects/thicket/badge/?version=latest)](http://thicket.readthedocs.io)
[![Code Style: Black](https://img.shields.io/badge/code%20style-black-000000.svg)](https://github.com/psf/black)

# Thicket

A Python-based toolkit for analyzing ensemble performance data. You can find
detailed documentation, along with tutorials of Thicket in the
[ReadtheDocs](https://thicket.readthedocs.io/en/latest/).

### Installation

To use thicket, install it with pip:

```
$ pip install llnl-thicket
```

Or, if you want to develop with this repo directly, run the install script from the
root directory, which will build the package and add the cloned directory to
your `PYTHONPATH`:

```
$ source install.sh
```

### Contact Us

You can direct any feature requests or questions to the Lawrence Livermore National
Lab's Thicket development team by emailing either Stephanie Brink (brink2@llnl.gov)
or Olga Pearce (pearce8@llnl.gov).

### Contributing

Thicket is an open-source project. We welcome contributions via pull requests,
and questions, feature requests, or bug reports via issues.

### License

Thicket is distributed under the terms of the MIT license.

All contributions must be made under the MIT license. Copyrights in the
Thicket project are retained by contributors. No copyright assignment is
required to contribute to Thicket.

See [LICENSE](https://github.com/llnl/thicket/blob/develop/LICENSE) and
[NOTICE](https://github.com/llnl/thicket/blob/develop/NOTICE) for details.

SPDX-License-Identifier: MIT

LLNL-CODE-834749
